import{j as e}from"./vendor-motion-k_x_E260.js";import{j as r,L as n,B as i,C as c,A as d}from"./index-Buswmged.js";import{o}from"./vendor-icons-BDy0XSiX.js";import"./vendor-react-BaJ9Uc06.js";function g(){const a=r();if(a._loading)return e.jsx(n,{label:"Loading alerts…"});const s=a.alerts;return e.jsxs("div",{className:"space-y-6",children:[e.jsxs("div",{className:"flex items-center justify-between",children:[e.jsx("h2",{className:"text-lg font-bold",children:"Alerts"}),e.jsx(i,{color:s.length>0?"red":"green",children:s.length===0?"All clear":`${s.length} alert${s.length!==1?"s":""}`})]}),s.length===0&&e.jsx(c,{children:e.jsxs("div",{className:"flex items-center gap-3 py-4",children:[e.jsx(o,{size:20,className:"text-emerald-400"}),e.jsx("span",{className:"text-sm text-gray-400",children:"No active alerts"})]})}),e.jsx("div",{className:"space-y-3",children:s.map((t,l)=>e.jsx(d,{alert:t},l))})]})}export{g as default};
